==> dde-file-manager_4.4.7.orig.tar.xz: dde-file-manager-4.4.7/usb-device-formatter/translations/usb-device-formatter_tr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="tr" version="2.1">
<context>
    <name>FinishPage</name>
    <message>
        <location filename="../view/finishpage.cpp" line="18"/>
        <source>Format successfully</source>
        <translation>Biçimlendirme başarılı</translation>
    </message>
</context>
<context>
    <name>FormatingPage</name>
    <message>
        <location filename="../view/formatingpage.cpp" line="19"/>
        <source>Formating, please wait for a minute...</source>
        <translation>Biçimlendiriliyor, lütfen bir dakika bekleyiniz...</translation>
    </message>
</context>
<context>
    <name>MainPage</name>
    <message>
        <location filename="../view/mainpage.cpp" line="85"/>
        <source>Type</source>
        <translation>Tür</translation>
    </message>
    <message>
        <location filename="../view/mainpage.cpp" line="104"/>
        <source>Label</source>
        <translation>Etiket</translation>
    </message>
    <message>
        <location filename="../view/mainpage.cpp" line="113"/>
        <source>Fast format</source>
        <translation>Hızlı biçimlendirme</translation>
    </message>
    <message>
        <location filename="../view/mainpage.cpp" line="130"/>
        <source>This operation will clear all data from your device.</source>
        <translation>Bu işlem aygıtınızdaki tüm verileri silecektir.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../view/mainwindow.cpp" line="56"/>
        <location filename="../view/mainwindow.cpp" line="78"/>
        <source>Format</source>
        <translation>Biçimlendir</translation>
    </message>
    <message>
        <location filename="../view/mainwindow.cpp" line="165"/>
        <source>Continue</source>
        <translation>Devam Et</translation>
    </message>
    <message>
        <location filename="../view/mainwindow.cpp" line="170"/>
        <source>Formatting...</source>
        <translation>Biçimlendiriliyor...</translation>
    </message>
    <message>
        <location filename="../view/mainwindow.cpp" line="194"/>
        <source>Done</source>
        <translation>Bitti</translation>
    </message>
    <message>
        <location filename="../view/mainwindow.cpp" line="205"/>
        <source>Failed to format</source>
        <translation>Biçimleme başarısız oldu</translation>
    </message>
    <message>
        <location filename="../view/mainwindow.cpp" line="201"/>
        <source>Quit</source>
        <translation>Çık</translation>
    </message>
    <message>
        <location filename="../view/mainwindow.cpp" line="202"/>
        <source>Your disk is removed when formatting</source>
        <translation>Diskiniz  biçimlendirilirken kaldırılacaktır</translation>
    </message>
    <message>
        <location filename="../view/mainwindow.cpp" line="206"/>
        <source>Reformat</source>
        <translation>Yeniden biçimlendir</translation>
    </message>
</context>
<context>
    <name>MessageDialog</name>
    <message>
        <location filename="../dialogs/messagedialog.cpp" line="19"/>
        <source>OK</source>
        <translation>Tamam</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="71"/>
        <source>Device does not exist</source>
        <translation>Aygıt mevcut değil</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="80"/>
        <source>Cannot format local device</source>
        <translation>Yerel aygıt biçimlendirilemiyor</translation>
    </message>
</context>
<context>
    <name>WarnPage</name>
    <message>
        <location filename="../view/warnpage.cpp" line="19"/>
        <source>Formating operation will clear all data from your disk, are you sure to continue? This option can not be restored.</source>
        <translation>Biçimlendirme işlemi diskinizdeki tüm verileri silecektir, devam etmek istediğinize emin misiniz? Bu seçenek geri alınamaz.</translation>
    </message>
</context>
</TS>

==> dde-file-manager_4.4.8.5.orig.tar.xz: dde-file-manager-4.4.8.5/usb-device-formatter/translations/usb-device-formatter_tr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="tr" version="2.1">
<context>
    <name>FinishPage</name>
    <message>
        <location filename="../view/finishpage.cpp" line="18"/>
        <source>Format successfully</source>
        <translation>Biçimlendirme başarılı</translation>
    </message>
</context>
<context>
    <name>FormatingPage</name>
    <message>
        <location filename="../view/formatingpage.cpp" line="19"/>
        <source>Formating, please wait for a minute...</source>
        <translation>Biçimlendiriliyor, lütfen bir dakika bekleyiniz...</translation>
    </message>
</context>
<context>
    <name>MainPage</name>
    <message>
        <location filename="../view/mainpage.cpp" line="85"/>
        <source>Type</source>
        <translation>Tür</translation>
    </message>
    <message>
        <location filename="../view/mainpage.cpp" line="104"/>
        <source>Label</source>
        <translation>Etiket</translation>
    </message>
    <message>
        <location filename="../view/mainpage.cpp" line="113"/>
        <source>Fast format</source>
        <translation>Hızlı biçimlendirme</translation>
    </message>
    <message>
        <location filename="../view/mainpage.cpp" line="130"/>
        <source>This operation will clear all data from your device.</source>
        <translation>Bu işlem aygıtınızdaki tüm verileri silecektir.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../view/mainwindow.cpp" line="56"/>
        <location filename="../view/mainwindow.cpp" line="78"/>
        <source>Format</source>
        <translation>Biçimlendir</translation>
    </message>
    <message>
        <location filename="../view/mainwindow.cpp" line="165"/>
        <source>Continue</source>
        <translation>Devam et</translation>
    </message>
    <message>
        <location filename="../view/mainwindow.cpp" line="170"/>
        <source>Formatting...</source>
        <translation>Biçimlendiriliyor...</translation>
    </message>
    <message>
        <location filename="../view/mainwindow.cpp" line="194"/>
        <source>Done</source>
        <translation>Bitti</translation>
    </message>
    <message>
        <location filename="../view/mainwindow.cpp" line="205"/>
        <source>Failed to format</source>
        <translation>Biçimleme başarısız oldu</translation>
    </message>
    <message>
        <location filename="../view/mainwindow.cpp" line="201"/>
        <source>Quit</source>
        <translation>Çık</translation>
    </message>
    <message>
        <location filename="../view/mainwindow.cpp" line="202"/>
        <source>Your disk is removed when formatting</source>
        <translation>Diskiniz  biçimlendirilirken kaldırılacaktır</translation>
    </message>
    <message>
        <location filename="../view/mainwindow.cpp" line="206"/>
        <source>Reformat</source>
        <translation>Yeniden biçimlendir</translation>
    </message>
</context>
<context>
    <name>MessageDialog</name>
    <message>
        <location filename="../dialogs/messagedialog.cpp" line="19"/>
        <source>OK</source>
        <translation>Tamam</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="71"/>
        <source>Device does not exist</source>
        <translation>Aygıt mevcut değil</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="80"/>
        <source>Cannot format local device</source>
        <translation>Yerel aygıt biçimlendirilemiyor</translation>
    </message>
</context>
<context>
    <name>WarnPage</name>
    <message>
        <location filename="../view/warnpage.cpp" line="19"/>
        <source>Formating operation will clear all data from your disk, are you sure to continue? This option can not be restored.</source>
        <translation>Biçimlendirme işlemi diskinizdeki tüm verileri silecektir, devam etmek istediğinize emin misiniz? Bu seçenek geri alınamaz.</translation>
    </message>
</context>
</TS>
